Katapayadi
===========

Katapayadi Sankhya
------------------

`Katapayadi sankhya <http://en.wikipedia.org/wiki/Katapayadi_sankhya>`_ is
a simplification of `Aryabhata <http://en.wikipedia.org/wiki/Aryabhata>`_
's `Sanskrit numerals <http://en.wikipedia.org/wiki/Sanskrit_numerals>`_ ,
due probably to `Haridatta <http://www.google.com/search?hl=en&q=Haridatta&btnG=Google+Search>`_ from
Kerala.  In Malayalam it is also known as 'Paralperu' For eg:
ചണ്ഡാംശുചന്ദ്രാധമകുംഭിപാല represents 31415926536 which is
π*1000000000000000 More examples in Malayalam are given in this `page <http://ml.wikipedia.org/wiki/Paralperu>`_

for more  read the `docs <http://katapayadi.readthedocs.org/en/latest/>`_
